/*****************************************************************************
 *   rtctest.c:  main C entry file for NXP LPC288x Family Microprocessors
 *
 *   Copyright(C) 2006, NXP Semiconductor
 *   All rights reserved.
 *
 *   History
 *   2006.07.13  ver 1.00    Prelimnary version, first Release
 *
******************************************************************************/
#include "LPC288x.h"                        /* LPC2xxx definitions */
#include "type.h"
#include "irq.h"
#include "timer.h"
#include "target.h"
#include "rtc.h"

extern volatile DWORD alarm_on;
RTCTime local_time, alarm_time, current_time;

/*****************************************************************************
**   Main Function  main()
******************************************************************************/
int main (void)
{
  TargetResetInit();
  	    		
  /* Initialize RTC module */
  RTCInit();

  local_time.RTC_Sec = 0;
  local_time.RTC_Min = 0;
  local_time.RTC_Hour = 0;
  local_time.RTC_Mday = 14;
  local_time.RTC_Wday = 2;
  local_time.RTC_Yday = 0;		/* Current date */
  local_time.RTC_Mon = 5;
  local_time.RTC_Year = 2007;
  RTCSetTime( local_time );		/* Set local time */

  alarm_time.RTC_Sec = 0;
  alarm_time.RTC_Min = 0;
  alarm_time.RTC_Hour = 0;
  alarm_time.RTC_Mday = 15;
  alarm_time.RTC_Wday = 2;
  alarm_time.RTC_Yday = 0;			/* alarm date */
  alarm_time.RTC_Mon = 5;
  alarm_time.RTC_Year = 2007;
  RTCSetAlarm( alarm_time );		/* set alarm time */

  /* mask off alarm mask, turn on IMMIN and IMYEAR in the counter 
  increment interrupt register */
  RTCSetAlarmMask(AMRSEC|AMRMIN|AMRHOUR|AMRDOM|AMRDOW|AMRDOY|AMRMON|AMRYEAR);
  RTC_CIIR = IMMIN | IMYEAR;
  
  /* install RTC timer handler mainly for alarm control */
  if ( install_IRQ(7, 1, RTCHandler ) == FALSE )
  {
	return( FALSE );
  }
  INT_REQ7=(1<<28)|(1<<27)|(1<<26)|(1<<16)|0x1;
  INT_VECTOR0=IRQ_TABLE_BASE & MASK_INDEX;
    
  RTCStart();

  while (1) 
  {					/* Loop forever */
	current_time = RTCGetTime();
	if ( alarm_on != 0 )
	{
	  alarm_on = 0;
	  /* Get current time when alarm is on */
	  current_time = RTCGetTime();	
	}
  }
  return 0;
}

/******************************************************************************
**                            End Of File
******************************************************************************/
